httpproxy

package
v0.0.0-...-5238b66 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 1, 2024 License: Apache-2.0 Imports: 4 Imported by: 0

README

Location ID

  • Default locationID for the proxlyet is proxylet
  • Default locationID for the proxy server is proxy

the Default ID for both services can be updated by setting DEFAULT_LOCATION_ID environment variable

Max bytes read from tcp socket

  • this value can be updated by setting env variable MAX_BYTES_TCP defaults to 1024 bytes

Documentation

Index

Constants

const (
	NATS_MSG_PREFIX                = "natssyncmsg"
	HTTP_PROXY_API_ID              = "httpproxy"
	HTTPS_PROXY_API_ID             = "httpsproxy"
	HTTPS_PROXY_CONNECTION_REQUEST = "httpsproxy-connection"
	TestRandomReplyMessageUUID     = "08026b1a-7341-4d69-880b-7db9897a8a17"
)

Variables

This section is empty.

Functions

func GetEnvWithDefaults

func GetEnvWithDefaults(envKey string, defaultVal string) string

func MakeHttpsMessageSubject

func MakeHttpsMessageSubject(targetLocationID string, connectionID string) string

func MakeMessageSubject

func MakeMessageSubject(targetLocationID string, appID string) string

func MakeReplyMessageSubject

func MakeReplyMessageSubject(locationID string, unitTestMode bool) string

MakeReplyMessageSubject: makes a random reply subject that will route from the client (south side) to the server side if unitTestMode is set, TestRandomReplyMessageUUID will be used instead of a true random uuid,

Types

This section is empty.

Directories

Path Synopsis
* Copyright (c) The One True Way 2020.
* Copyright (c) The One True Way 2020.

Jump to