Documentation
¶
Index ¶
- Constants
- func GetEnvWithDefaults(envKey string, defaultVal string) string
- func MakeHttpsMessageSubject(targetLocationID string, connectionID string) string
- func MakeMessageSubject(targetLocationID string, appID string) string
- func MakeReplyMessageSubject(locationID string, unitTestMode bool) string
Constants ¶
const ( NATS_MSG_PREFIX = "natssyncmsg" HTTP_PROXY_API_ID = "httpproxy" HTTPS_PROXY_API_ID = "httpsproxy" HTTPS_PROXY_CONNECTION_REQUEST = "httpsproxy-connection" TestRandomReplyMessageUUID = "08026b1a-7341-4d69-880b-7db9897a8a17" )
Variables ¶
This section is empty.
Functions ¶
func GetEnvWithDefaults ¶
func MakeHttpsMessageSubject ¶
func MakeMessageSubject ¶
func MakeReplyMessageSubject ¶
MakeReplyMessageSubject: makes a random reply subject that will route from the client (south side) to the server side if unitTestMode is set, TestRandomReplyMessageUUID will be used instead of a true random uuid,
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.